@@ -39,6 +39,12 @@ def get_parser():
                         type=valid_path,
                         help='the local path to the git repository')
 
+    parser.add_argument(action='store',
+                        dest='host',
+                        type=str,
+                        choices=['github', 'gitlab'],
+                        help='the source code versioning host')
+
     parser.add_argument(action='store',
                         dest='owner',
                         type=str,
@@ -86,6 +92,7 @@ def main():
     repository_miner = RepositoryMiner(access_token=token,
                                        path_to_repo=args.path_to_repo,
                                        branch=args.branch,
+                                       host=args.host,
                                        repo_owner=args.owner,
                                        repo_name=args.name)
 
